import logging
from typing import Annotated

import cyclopts
from cyclopts import Group, Parameter

from lineshape_tools.cli import (
    analyze_dynmat,
    collect,
    compute_dynmat,
    compute_lineshape,
    convert_from_phonopy,
    gen_confs,
    gen_ft_config,
)

app = cyclopts.App(help_format="md")
app.meta.group_parameters = Group("Commands")

for func in (
    analyze_dynmat,
    collect,
    compute_dynmat,
    compute_lineshape,
    convert_from_phonopy,
    gen_confs,
    gen_ft_config,
):
    app.command()(func)


@app.meta.default
def _app_launcher(
    *tokens: Annotated[str, Parameter(show=False, allow_leading_hyphen=True)],
    verbose: Annotated[bool, Parameter(negative="--quiet")] = False,
) -> None:
    fmt = "%(asctime)s %(levelname)s %(name)s: %(message)s" if verbose else "[*] %(message)s"
    log_level = logging.DEBUG if verbose else logging.INFO

    logging.basicConfig(level=log_level, format=fmt, encoding="utf-8")

    # remove logging from imported libraries, wow this is a monster of a line
    logging.getLogger().handlers[0].addFilter(logging.Filter(name=__name__.split(".")[0]))

    logging.getLogger(__name__).debug("starting application")
    app(tokens)


if __name__ == "__main__":
    app.meta()



"""The lineshape_tools package."""

__author__ = "Mark E. Turiansky"
__email__ = "mark.e.turiansky.ctr@us.navy.mil"
__version__ = "0.1.2"
__copyright__ = "Copyright (c) 2025 Mark E. Turiansky"
__license__ = "MIT"
